/*
 * HP8648 device support
 */

#include <epicsStdio.h>
#include <devCommonGpib.h>

/******************************************************************************
 *
 * The following define statements are used to declare the names to be used
 * for the dset tables.   
 *
 * A DSET_AI entry must be declared here and referenced in an application
 * database description file even if the device provides no AI records.
 *
 ******************************************************************************/
#define DSET_AI     devAiHP8648
#define DSET_AO     devAoHP8648
#define DSET_SI     devSiHP8648
#define DSET_BO     devBoHP8648

#include <devGpib.h> /* must be included after DSET defines */

#define TIMEOUT     1.0    /* I/O must complete within this time */
#define TIMEWINDOW  2.0    /* Wait this long after device timeout */

static char *efastOffOn[] = { "OFF", "ON", NULL };

/******************************************************************************
 * Array of structures that define all GPIB messages
 * supported for this type of instrument.
 ******************************************************************************/

static struct gpibCmd gpibCmds[] = {
    /* Param 0 - Identification string */
    {&DSET_SI,GPIBREAD,IB_Q_LOW,"*IDN?","%39[^\n]",0,80,0,0,NULL,NULL,NULL},
    /* Param 1 - set output power */
    {&DSET_AO,GPIBWRITE,IB_Q_LOW,NULL,":POW:AMPL %.1f DBM",0,64,0,0,0,NULL,NULL,NULL},
    /* Param 2 - set frequency */
    {&DSET_AO,GPIBWRITE,IB_Q_LOW,NULL,":FREQ:CW %.6f MHZ",0,64,0,0,0,NULL,NULL,NULL},
    /* Param 3 - turn output off/on */
    {&DSET_BO,GPIBEFASTO,IB_Q_LOW,"OUTP:STAT ",NULL,0,64,0,0,0,efastOffOn,NULL,NULL},
};

/* The following is the number of elements in the command array above.  */
#define NUMPARAMS sizeof(gpibCmds)/sizeof(struct gpibCmd)

/******************************************************************************
 * Initialize device support parameters
 *
 *****************************************************************************/
static long init_ai(int parm)
{
    if(parm==0) {
        devSupParms.name = "devHP8648";
        devSupParms.gpibCmds = gpibCmds;
        devSupParms.numparams = NUMPARAMS;
        devSupParms.timeout = TIMEOUT;
        devSupParms.timeWindow = TIMEWINDOW;
        devSupParms.respond2Writes = -1;
    }
    return(0);
}
